# -*- coding: utf-8 -*-

"""
Project name: Open Methodology for Security Tool Developers
Project URL: https://github.com/cr0hn/OMSTD

Copyright (c) 2014, cr0hn<-AT->cr0hn.com
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""


"""
API file
"""

__author__ = 'cr0hn - cr0hn<-at->cr0hn.com (@ggdaniel)'

__all__ = ["check_md5", "run_check_md5_hash"]

# Import data
from .lib.data import *
from .lib.check_md5 import check_md5


# ----------------------------------------------------------------------
def run_check_md5_hash(input_parameters):
    """
    Checks MD5 hash and return an Results object.

    :param input_parameters: Parameters object with config
    :type input_parameters: Parameters

    :return: Results object
    :rtype: Results

    :raises: TypeError
    """
    if not isinstance(input_parameters, Parameters):
        raise TypeError("Expected Parameters, got '%s' instead" % type(input_parameters))

    try:
        r = check_md5(input_parameters)

        return Results(plain_password=r,
                       is_hash_found=True)
    except HashNotFound as e:

        return Results(plain_password=None,
                       is_hash_found=False)


# ----------------------------------------------------------------------
def run_console(input_parameters):
    """
    Run for command line interface. It's make all steps of tool:
    - Looking find
    - Get password
    - Display into screen

    :param input_parameters: Parameters object with config
    :type input_parameters: Parameters

    :raises: TypeError
    """
    try:
        result = run_check_md5_hash(input_parameters)

        # Display plain text
        print("[**] Plain text FOUND!!!. Decoded password is ----> %s <----." % result.plain_password)
    except InvalidHashFormat as e:
        print("\n[!] An error was found while try to get password: %s\n" % e)
    except HashNotFound as e:
        print("\n[-] Plain text not found for hash '%s'" % input_parameters.md5_hash)